* Output options: all can be turned on/off by adding/ removing the NO;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=120 NOfmterr;
* Remove default title, turn on new HTML graphics;
  TITLE; ODS GRAPHICS ON; ODS LISTING;  

********************************************************************************;
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION       *******;
********************************************************************************;

* Paste in the folder address where "GSS_Example.xlsx" is saved after = before ;
%LET filesave= C:\Dropbox\21SP_PSQF6242\PSQF6242_Example5a;
* Using UIowa virtual desktop instead;
*%LET filesave= \\Client\C:\Dropbox\21SP_PSQF6242\PSQF6242_Example5a;

* We can then refer to the filesave place by putting & in front and . behind it;

* IMPORT GSS_Example.xlsx data using filesave reference and exact file name;
* from the Excel workbook in DATAFILE= location from SHEET= ;
* New SAS file is in "work" library place with name "Example5a";
* "GETNAMES" reads in the first row as variable names;
* DBMS=XLSX (can also use EXCEL or XLS for .xls files);
PROC IMPORT DATAFILE="&filesave.\GSS_Example.xlsx" 
            OUT=work.Example5a DBMS=XLSX REPLACE; 
     SHEET="GSS_Example"; 
     GETNAMES=YES; 
RUN;

* All data transformations must happen inside a DATA+SET combo to know where to use them;
DATA work.Example5a; SET work.Example5a;
* Create and label predictor variables for analysis (same as in Example 4);
  * Binary predictors for workclass;
    LvsM=.; LvsU=.; * Make new empty variables;
    IF workclass=1 THEN DO; LvsM=0; LvsU=0; END; * Replace each for lower;
    IF workclass=2 THEN DO; LvsM=1; LvsU=0; END; * Replace each for middle;
    IF workclass=3 THEN DO; LvsM=0; LvsU=1; END; * Replace each for upper; 
    LABEL LvsM="LvsM: Low=0 vs Mid=1 Class"
          LvsU="LvsU: Low=0 vs Upp=1 Class";
  * Center age at 18;
    age18=age-18; 
    LABEL age18= "age18: Age (0=18 years)";
  * Piecewise slopes for education;
    lessHS=.; gradHS=.; overHS=.; * Make three new empty variables;
    * Replace for educ less than 12;
      IF educ LT 12 THEN DO; lessHS=educ-11; gradHS=0; overHS=0;       END;
    * Replace for educ greater or equal to 12;
      IF educ GE 12 THEN DO; lessHS=0;       gradHS=1; overHS=educ-12; END;
      LABEL lessHS= "lessHS: Slope for Years Ed Less Than High School"
            gradHS= "gradHS: Bump for Graduating High School"
            overHS= "overHS: Slope for Years Ed After High School";
* Label outcome;
  LABEL income= "income: Annual Income in 1000s";
* Select cases complete on variables;
  WHERE NMISS(income,workclass,age,educ)=0;
RUN;
* Now dataset work.Example5a is ready to use; 

* Open output directory to save results to;
ODS RTF FILE="&filesave.\Example5a_SAS_Output.rtf" 
        STYLE=HTMLBlue STARTPAGE=NO BODYTITLE;

TITLE "SAS GLM Predicting Income from WorkClass, Age, and Education";
PROC GLM DATA=work.Example5a NAMELEN=100 PLOTS(UNPACK)=ALL;
* Combined model with all 7 slopes;
  MODEL income = LvsM LvsU age18 age18*age18 lessHS gradHS overHS  
                 / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
* Ask for missing model-implied group difference;
  ESTIMATE "Mid vs Upp Diff"  LvsM -1 LvsU 1;

* Replicate F-test and R2 for the model: includes all 7 slopes;
  CONTRAST "F-test (DFnum=7) for model" 
            LvsM 1, LvsU 1, age18 1, age18*age18 1, lessHS 1, gradHS 1, overHS 1; 
* Ask for F-test and semi-partial R2 for overall effect of workclass;
  CONTRAST "F-test (DFnum=2) for overall workclass" LvsM 1, LvsU 1;
* Ask for F-test and semi-partial R2 for overall effect of age;
  CONTRAST "F-test (DFnum=2) for overall age" age18 1, age18*age18 1;
* Ask for F-test and semi-partial R2 for overall effect of education;
  CONTRAST "F-test (DFnum=3) for overall education" lessHS 1, gradHS 1, overHS 1;

* Save for computing slope-specific effect sizes;
  ODS OUTPUT ParameterEstimates=ModelEstimates Estimates=ReqEstimates; 
RUN; QUIT; TITLE;

* Compute Cohen d effect size and r effect sizes;
DATA work.FinalEstimates; LENGTH Parameter $50; 
     SET work.ModelEstimates ReqEstimates; %LET df=726;
     CohenD=(2*tvalue)/SQRT(&df.); 
     EffectR=tvalue/SQRT((tvalue*tvalue)+&df.); 
RUN;

* Print effect sizes;
TITLE "Effect Sizes for Final Model";
PROC PRINT NOOBS DATA=work.FinalEstimates; 
     * Do not print intercept;
     WHERE INDEX(Parameter,"Intercept")=0;     
     VAR Parameter Estimate StdErr tvalue probt CohenD EffectR; 
RUN; TITLE;


* Close output;
ODS RTF CLOSE;

