// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

******************************************************************************
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION     *******
******************************************************************************

// Paste in the folder address where "GSS_Example.xlsx" is saved between " "
   global filesave "C:\Dropbox\21SP_PSQF6242\PSQF6242_Example5a"
// Using UIowa virtual desktop instead
   *global filesave "\\Client\C:\Dropbox\21SP_PSQF6242\PSQF6242_Example5a"

// We can then refer to the syntax variable "filesave" by putting $ in front

// IMPORT GSS_Example.xlsx data using filesave reference and exact file name
// To change all variable names to lowercase, remove "case(preserve")
   clear // Clear before means close any open data
   import excel "$filesave\GSS_Example.xlsx", case(preserve) firstrow clear 
// Clear after means re-import if it already exists (if need to start over)

// Create and label predictor variables for analysis (same as in Example 4)
// Binary predictors for workclass
   gen LvsM=. // Make two new empty variables
   gen LvsU=.
   replace LvsM=0 if workclass==1 // Replace each for lower
   replace LvsU=0 if workclass==1
   replace LvsM=1 if workclass==2 // Replace each for middle
   replace LvsU=0 if workclass==2
   replace LvsM=0 if workclass==3 // Replace each for upper
   replace LvsU=1 if workclass==3
   label variable LvsM "LvsM: Low=0 vs Mid=1 Class"
   label variable LvsU "LvsU: Low=0 vs Upp=1 Class"
// Center age at 18
   gen age18 = age-18
   label variable age18 "age18: Age (0=18 years)"
// Piecewise slopes for education
   gen lessHS=. // Make 3 new empty variables
   gen gradHS=.
   gen overHS=.
// Replace for educ less than 12
   replace lessHS=educ-11 if educ <  12
   replace gradHS=0       if educ <  12
   replace overHS=0       if educ <  12
// Replace for educ greater or equal to 12
   replace lessHS=0       if educ >= 12 
   replace gradHS=1       if educ >= 12
   replace overHS=educ-12 if educ >= 12
// Label variables
   label variable lessHS "lessHS: Slope for Years Ed Less Than High School"
   label variable gradHS "gradHS: Acute Bump for Graduating High School"
   label variable overHS "overHS: Slope for Years Ed After High School"
// Label outcome
   label variable income "income: Annual Income in 1000s"
// Select cases complete on variables of interest
   egen nmiss = rowmiss(income workclass age educ)
   drop if nmiss>0
// Now dataset is ready to use

// Save results to separate text file
   log using $filesave\Example5a_STATA_Output.log, replace 

   
display "STATA GLM Predicting Income from WorkClass, Age, and Education"
regress income c.LvsM c.LvsU c.age18 c.age18#c.age18 c.lessHS c.gradHS c.overHS, level(95)
// Ask for missing model-implied group difference
   lincom  c.LvsM*-1 + c.LvsU*1 // Mid vs Upp Diff 
// Replicate F-test for the model: includes all 7 slopes
   test (c.LvsM=0) (c.LvsU=0) (c.age18=0) (c.age18#c.age18=0) ///
        (c.lessHS=0) (c.gradHS=0) (c.overHS=0) 
// Ask for F-test for overall effect of workclass
   test (c.LvsM=0) (c.LvsU=0)
// Ask for F-test for overall effect of age		
   test (c.age18=0) (c.age18#c.age18=0)  
// Ask for F-test for overall effect of education
   test (c.lessHS=0) (c.gradHS=0) (c.overHS=0) 
		
display as result "STATA Reduced Model to Get SS for workclass (not included)"
regress income c.age18 c.age18#c.age18 c.lessHS c.gradHS c.overHS, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (40246.42433-34284.6688)/139423.2319 // sr2 for workclass = .04276013

display "STATA Reduced Model to Get SS for age (not included)"
regress income c.LvsM c.LvsU c.lessHS c.gradHS c.overHS, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (40246.42433-29022.8166)/139423.2319 // sr2 for age = .08050027

display "STATA Reduced Model to Get SS for education (not included)"
regress income c.LvsM c.LvsU c.age18 c.age18#c.age18, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (40246.42433-28994.6361)/139423.2319 // sr2 for education = .08070239

// Close log
log close  

       
       



